@@ -3,7 +3,7 @@ import time
 from openai import util
 from openai.api_resources.abstract import DeletableAPIResource, ListableAPIResource
 from openai.api_resources.abstract.engine_api_resource import EngineAPIResource
-from openai.error import TryAgain, InvalidRequestError
+from openai.error import InvalidRequestError, TryAgain
 
 
 class Completion(EngineAPIResource, ListableAPIResource, DeletableAPIResource):
@@ -33,4 +33,4 @@ class Completion(EngineAPIResource, ListableAPIResource, DeletableAPIResource):
                 if timeout is not None and time.time() > start + timeout:
                     raise
 
-                util.log_info("Waiting for snapshot to warm up", error=e)
+                util.log_info("Waiting for model to warm up", error=e)
